# import the necessary packages
# from keras.preprocessing.image import img_to_array
from keras.models import load_model
import numpy as np
import pickle
import cv2
import os

#image dims must be the same as the model input
imageDimensions = (224, 224)
modelPath = "./models"

try:
	input = raw_input
except NameError:
	pass

def main():

	#get list of models available
	models = []
	for i in os.walk(modelPath):
		if i[0] == modelPath:
			models = i[1]

	print("Models found: ")
	print(models) 

	#load users model and associated labels
	modelName = input("Choose model: ")
	labelFile = os.path.join(modelPath, modelName, "labels")
	modelFile = os.path.join(modelPath, modelName, "model")

	model = None
	labelBinariser = None

	model = load_model(modelFile)

	with open(labelFile, "rb") as f:
		labelBinariser = pickle.load(f)

	print("Enter path to directory of directories for classification")
	imageDirectory = input("eg. folder containing 'saturn' folder of images: ")

	classes = []
	correct = 0
	incorrect = 0

	for folder in os.walk(imageDirectory):
		if folder[0] == imageDirectory:
			classes = folder[1]

	for label in classes:
		for folder in os.walk(os.path.join(imageDirectory, label)):

			images = folder[2]

			for image in images:

				#load image
				img = None
				imageFile = os.path.join(imageDirectory, label, image)

				#imread will not fail if file does not exist - just returns None
				#so we call resize on it which we need anyway, will will trigger the exception if the file doesnt exist
				img = cv2.imread(imageFile, 1)
				img = img.astype("float") / 255.0
				img = cv2.resize(img, (imageDimensions[1], imageDimensions[0]))

				#expand array - model by default expects array of images
				img = np.expand_dims(img, axis=0)
				#predict image
				probabilities = model.predict(img)

				#show model output probabilities
				probs = list(zip(probabilities[0], labelBinariser.classes_))
				print("Real: " + str(label) + " Predicted: " + str(max(probs)[1]))
				print(probs)

				if label == max(probs)[1]:
					correct += 1
				else:
					incorrect += 1

	print("Total correct predictions: " + str(correct))
	print("Total incorrect predictions: " + str(incorrect))

if __name__ == '__main__':
	main()
