# import the necessary packages
# from keras.preprocessing.image import img_to_array
from keras.models import load_model
import numpy as np
import pickle
import cv2
import os

#image dims must be the same as the model input
imageDimensions = (224, 224)
modelPath = "./models"

try:
	input = raw_input
except NameError:
	pass

def main():

	#get list of models available
	models = []
	for i in os.walk(modelPath):
		if i[0] == modelPath:
			models = i[1]

	print("Models found: ")
	print(models) 

	#load users model and associated labels
	modelName = input("Choose model: ")
	labelFile = os.path.join(modelPath, modelName, "labels")
	modelFile = os.path.join(modelPath, modelName, "model")

	model = None
	labelBinariser = None

	model = load_model(modelFile)

	with open(labelFile, "rb") as f:
		labelBinariser = pickle.load(f)

	#load image
	img = None
	imageFile = input("Enter path to image: ")
	
	#imread will not fail if file does not exist - just returns None
	#so we call resize on it which we need anyway, will will trigger the exception if the file doesnt exist
	img = cv2.imread(imageFile, 1)
	img = img.astype("float") / 255.0
	img = cv2.resize(img, (imageDimensions[1], imageDimensions[0]))

	#expand array - model by default expects array of images
	img = np.expand_dims(img, axis=0)
	#predict image
	probabilities = model.predict(img)

	#show model output probabilities
	print("================")
	print("Best guess:")
	probs = list(zip(probabilities[0], labelBinariser.classes_))
	print(max(probs)[1])

	print("Probabilities:")
	print(list(zip(labelBinariser.classes_, probabilities[0])))
	print("Note if probabilities show up as nan (not a number), most likely reason is insufficient training")

if __name__ == '__main__':
	main()