from keras.models import Sequential
from keras.layers.normalization import BatchNormalization
from keras.layers.convolutional import Conv2D
from keras.layers.convolutional import MaxPooling2D
from keras.layers.core import Flatten
from keras.layers.core import Dropout
from keras.layers.core import Dense
from keras import backend as K

def buildVGG16(width, height, depth, classes):

	model = Sequential()

	#2x conv + max pool
	model.add(Conv2D(64, (3, 3), activation="relu", padding="same", input_shape=(height, width, depth)))
	model.add(BatchNormalization())
	model.add(Conv2D(64, (3, 3), activation="relu", padding="same"))
	model.add(BatchNormalization())
	model.add(MaxPooling2D(pool_size=(2, 2), strides=(2, 2)))
	model.add(Dropout(0.25))

	#2x conv + max pool
	model.add(Conv2D(128, (3, 3), activation="relu", padding="same"))
	model.add(BatchNormalization())
	model.add(Conv2D(128, (3, 3), activation="relu", padding="same"))
	model.add(BatchNormalization())
	model.add(MaxPooling2D(pool_size=(2, 2), strides=(2, 2)))
	model.add(Dropout(0.25))

	#3x conv + max pool
	model.add(Conv2D(256, (3, 3), activation="relu", padding="same"))
	model.add(BatchNormalization())
	model.add(Conv2D(256, (3, 3), activation="relu", padding="same"))
	model.add(BatchNormalization())
	model.add(Conv2D(256, (3, 3), activation="relu", padding="same"))
	model.add(BatchNormalization())
	model.add(MaxPooling2D(pool_size=(2, 2), strides=(2, 2)))
	model.add(Dropout(0.25))

	#3x conv + max pool
	model.add(Conv2D(512, (3, 3), activation="relu", padding="same"))
	model.add(BatchNormalization())
	model.add(Conv2D(512, (3, 3), activation="relu", padding="same"))
	model.add(BatchNormalization())
	model.add(Conv2D(512, (3, 3), activation="relu", padding="same"))
	model.add(BatchNormalization())
	model.add(MaxPooling2D(pool_size=(2, 2), strides=(2, 2)))
	model.add(Dropout(0.25))

	#3x conv + max pool
	model.add(Conv2D(512, (3, 3), activation="relu", padding="same"))
	model.add(BatchNormalization())
	model.add(Conv2D(512, (3, 3), activation="relu", padding="same"))
	model.add(BatchNormalization())
	model.add(Conv2D(512, (3, 3), activation="relu", padding="same"))
	model.add(BatchNormalization())
	model.add(MaxPooling2D(pool_size=(2, 2), strides=(2, 2)))
	model.add(Dropout(0.25))

	#2x fully connected + softmax
	model.add(Flatten())
	model.add(Dense(4096))
	model.add(Activation("relu"))
	model.add(Dense(4096))
	model.add(Activation("relu"))
	model.add(Dense(classes))
	model.add(Activation("softmax"))
	model.add(BatchNormalization())
	model.add(Dropout(0.5))

	return model