from keras.models import Sequential
from keras.layers.normalization import BatchNormalization
from keras.layers.convolutional import Conv2D
from keras.layers.convolutional import MaxPooling2D
from keras.layers.core import Activation
from keras.layers.core import Flatten
from keras.layers.core import Dropout
from keras.layers.core import Dense
from keras import backend as K

def buildVGG(width, height, depth, classes):

	model = Sequential()

	#2x conv at 32 + max pool
	model.add(Conv2D(32, (3, 3), padding="same", activation="relu", input_shape=(height, width, depth)))
	model.add(BatchNormalization())
	model.add(MaxPooling2D(pool_size=(2, 2)))
	model.add(Dropout(0.25))

	#2x conv at 64 + max pool
	model.add(Conv2D(64, (3, 3), padding="same", activation="relu"))
	model.add(BatchNormalization())
	model.add(MaxPooling2D(pool_size=(2, 2)))
	model.add(Dropout(0.25))

	#2x conv at 128
	model.add(Conv2D(128, (3, 3), padding="same", activation="relu"))
	model.add(BatchNormalization())
	model.add(Conv2D(128, (3, 3), padding="same", activation="relu"))
	model.add(BatchNormalization())
	model.add(MaxPooling2D(pool_size=(2, 2)))
	model.add(Dropout(0.25))

	#Fully connected layer and softmax classifier
	model.add(Flatten())
	model.add(Dense(2048))
	model.add(Activation("relu"))
	model.add(BatchNormalization())
	model.add(Dropout(0.5))
	model.add(Dense(classes))
	model.add(Activation("softmax"))

	return model
